% The xDSL simulation tool - The xDSL definitions
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Functions to set up experiments
%
%  ETSI_VDSL_defs           Set up "everything" for an ETSI VDSL experiment
%  ANSI_VDSL_defs           Set up "everything" for an ANSI VDSL experiment
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Functions for defining cables
%
%   ansi_cablesADSL         Define cables used in ANSI ADSL
%   ansi_cablesVDSL         Define cables used in ANSI VDSL
%   etsi_cablesADSL         Define cables used in ETSI ASDL 
%   etsi_cablesSDSL         Define cables used in ETSI SSDL 
%   etsi_cablesVDSL         Define cables used in ETSI VSDL
%   etsi_cablesADSL_extra   Define some other cables models used in ETSI ASDL 
%   itu_cablesADSL          Define cables used in ITU ASDL 
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Functions for defining loops
%
%   ansi_loopsVDSL          Defines ANSI VDSL loops
%   etsi_loopsADSL          Defines ETSI ADSL loops
%   etsi_loopsSDSL          Defines ETSI SDSL loops
%   etsi_loopsVDSL          Defines ETSI VDSL loops
%   fsan_loopsVDSL          Defines FSAN VDSL loops
%   etsi_loopsSDSLdeflen.m  Defines default values for ETSI SDSL testloops
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Functions for defining noise
%
%   ansi_noisesVDSL         Defines ANSI VDSL noise tfplans
%   etsi_noisesADSL         Defines ETSI ADSL noise tfplans
%   etsi_noisesADSL2plus    Defines ETSI ADSL2plus noise tfplans
%   etsi_noisesSDSL         Defines ETSI SDSL noise tfplans
%   etsi_noisesVDSL         Defines ETSI VDSL noise tfplans
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Functions for defining time and frequency plans
%
%   ansi_tfplanHAM          Define ANSI HAM band tf-plan
%   etsi_tfplanHAM          Define ETSI HAM band tf-plan
%   itu_tfplanHAM           Define ITU HAM band tf-plan
%
%   etsi_tfplansVDSL        Define ETSI VDSL tf-plans
%   etsi_tfplansVDSLDMT     Define ETSI VDSL-DMT tf-plans
%   etsi_tfplansVDSL_old    Obsolete ETSI VDSL tf-plans
%   etsi_tfplansSDSL        Define ETSI SDSL tf-plans
%   etsi_tfplansSDSL_RC     Define some older ETSI SDSL tf-plans
%   etsi_tfplansESDSL       Define ETSI ESDSL tf-plans
%   etsi_tfplansADSL        Define ETSI ADSL tf-plans
%   etsi_tfplansLegacy      Define ETSI legacy systems (ISDN, HDSL) tf-plans
%   itu_tfplansADSL2        Define ITU ADSL2 tf-plans
%   special_modelsVDSL      Define special VDSL tf-plans
%   fsan_modelsMISC         Define standard "alien" tf-plans
%   itu_modelsPNT           Define ITU-T PNT model
%   activeVDSLf             Generates a vector with active frequencies
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Functions for defining linecode specifics
%
%   etsi_lcdefsVDSL         Set up lc models for ETSI VDSL
%   etsi_lcdefsESDSL        Set up lc models for ETSI ESDSL
%   etsi_lcdefsHDSL         Set up lc models for ETSI HDSL
%   etsi_lcdefsISDN         Set up lc models for ETSI ISDN
%   etsi_lcdefsADSL         Set up lc models for ETSI ADSL
%   etsi_lcdefsSDSL         Set up lc models for ETSI SDSL
%   etsi_lcdefsSDSL_SpecificRates     Set up some specific-rate SDSL models
%   etsi_lcdefsSDSL_SpecificRates_RC  Set up some old specific-rate SDSL models
%   lcDefHDSL2B1Q           Define lc model for HDSL 2B1Q
%   lcDefHDSLCAP            Define lc model for HDSL CAP
%   lcDefADSLDMT            Define lc model for ADSL DMT
%   lcDefVDSLDMT            Define lc model for VDSL DMT
%   lcDefVDSLSCM            Define lc model for VDSL SCM
%   lcPrintDMT              Print DMT lc model
%   lcPrintSCM              Print SCM lc model
%   lcPrintHDSL             Print SDSL lc model
%   lcPrintSDSL             Print SDSL lc model
%   lcPrintTheo             Print Theo lc model
%   ETSI_SDSL_traffic2lctf  Help routine to set up suitable SDSL lcdefs
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Functions for defining PSD masks
%
%   etsi_masksVDSL          Defines the PSD masks for ETSI VDSL
%   etsi_modelsVDSL_SCM     Sets up the SCM PSDs according to ETSI VDSL part 2
%   modelPSD_HDSL           Defines a function that models HDSL PSD
%   modelPSD_ISDN_PRA       Defines a function that models ISDN PRA PSD
%   modelPSD_HDSL_2B1Q      Defines a function that models HDSL 2B1Q PSD
%   modelPSD_ISDN_2B1Q      Defines a function that models ISDN 2B1Q PSD
%   modelPSD_T1             Defines a function that models T1 PSD
%   modelPSD_SDSL_sym_ver1  Defines a function that models symmetrical SDSL
%   modelPSD_SDSL_sym_ver2  Another function that models symmetrical SDSL
%   modelPSD_SDSL_asym      Defines a function that models asymmetrical SDSL
%   etsi_SDSLmodelParameters Sets up PSD parameters for SDSL
%   modelPSD_SDSL           Defines a function that models sym and asym SDSL
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Post processing and results
%
%   calcResultDMT      	    Calculate resulting bit rates for DMT
%   calcResultHDSL      	Calculate resulting bit rates for HDSL
%   calcResultSDSL  	    Calculate resulting bit rates for SDSL
%   calcResultSCM  	    Calculate resulting bit rates for SCM
%   calcResultSCM_cRate	    Local routine for calcResultSCM
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Misc
%  Content  		    This file
%
%% ===========================================================================

%% ===========================================================================
% Copyright (C):
%       2000-2009 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Description   : The contents of the xdsldefs directory
%
% File          : Content.m
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%
% CVS:       $Id: Contents.m 752 2009-01-02 13:03:52Z tono $
%% ===========================================================================
% Change History
%      2000-09-17 (ToNo) Created
%      2002-08-23 (ToNo) Updated after "the big rename"
%      2005-01-12 (ToNo) Updated after merge of many ETSI SpM routines
%% ===========================================================================
