function tfplist = ansi_noisesVDSL(tfplist)
%% ===========================================================================
%ansi_noisesVDSL(tfplist) - Sets up the tfplan for ANSI (FSAN) noise models
%
% Parameter:    tfplist	        Structure describing the time and freq plan
% Returns:      tfplist		Structure describing the time and freq plan
%
% Example(s):
%   ex.tfplist = ansi_noisesVDSL(ex.tfplist);             Add to existing tfplist
%   tfplan=getList(ex.tfplist,'ANSI-VDSL-NoiseA') ;  Get this VDSL noise
%
%   ex.tfplist = ansi_noisesVDSL([]);                     Create a new tfplist
%   tfplan=getList(ex.tfplist,'ANSI-VDSL-NoiseF');   Get this VDSL noise
%
% Reference:
%    FTW's xDSLsimu manual
% Mask definitions:
%    Reference T1E1.4/99 -438R2
%    ITU-T LB-097R2 and personal communication with Vladimir Oksman
%% ===========================================================================

%% ===========================================================================
% Copyright (C):                                        
%       2000-2009 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@ftw.at)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%
% CVS:       $Id: ansi_noisesVDSL.m 752 2009-01-02 13:03:52Z tono $
%% ===========================================================================
% Change History
%      2000-02-09 (ToNo) Created
%      2000-04-05 (UvAn) Added frequency axis for the call to calcPSD
%      2000-05-26 (UvAn) Added possibillities to fix the bitrate 
%      2004-11-12 (ToNo) Added Noise D according to the proposal to
%                        ITU-T by Vladimir Oksman    
%% ===========================================================================

%% ===========================================================================
% Use a template, as order is important!

def_tfplan = templateTFP;

%% ===========================================================================
% ANSI VDSL (FSAN based) noise models
%-------------------

% Models Alien crosstalk from a disturber that shall be coupled with and NEXT
% and FEXT functions 
% Reference T1E1.4/99 -438R2

% Alien noise spectra at: NT = upstream, LT = downstream

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ANSI-VDSL-NoiseA';
tmp_tfplan.PSD.downstream='calcPSD([1 -26.0 30e3 -34.0 50e3 -39.0 65e3 -42.0 100e3 -43.0 400e3 -49.5 550e3 -52.5 1104e3 -60.0 1500e3 -79.0 2500e3 -115.0 3550e3 -139.0 10000e3 -140.0 30000e3 -140.0],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream='calcPSD([1 -24.5 30e3 -25.0 65e3 -31.0 130e3 -31.0 250e3 -49.0 400e3 -78.0 650e3 -81.5 1104e3 -81.5 1400e3 -83.0 2750e3 -103.5 4000e3 -104.0 30000e3 -104.0],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ANSI-VDSL-NoiseF';
tmp_tfplan.PSD.downstream='calcPSD([1 -24.5 30e3 -25.5 65e3 -32.0 130e3 -33.0 250e3 -33.5 1104e3 -33.5 1600e3 -52.0 2250e3 -52.0 2650e3 -60.0 3000e3 -84.5 3200e3 -84.5 3500e3 -67.0 4000e3 -64.5 4500e3 -77.5 11500e3 -103.0 30000e3 -103.5],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream='calcPSD([1 -24.5 30e3 -25.5 65e3 -31.0 130e3 -31.0 250e3 -47.5 300e3 -47.0 550e3 -43.5 900e3 -43.5 1104e3 -45.5 1500e3 -60.0 1600e3 -60.0 1900e3 -52.0 2250e3 -52.0 2650e3 -60.0 3000e3 -84.5 3200e3 -84.5 3500e3 -67.0 4000e3 -64.5 4500e3 -77.5 11500e3 -103.0 30000e3 -103.5],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);


% Noise D suggested by Vladimir Oksman to ITU-T, this noise can be seen as
% Noise F without T1. That is, 10 ADSL + 16 ISDN + 2 HDSL.
tmp_tfplan=def_tfplan;
tmp_tfplan.name='ANSI-VDSL-NoiseD';
tmp_tfplan.PSD.downstream='calcPSD([1 -25.0 0.01e6 -25.0 0.03e6 -26.0 0.05e6 -29.6 0.065e6 -32.0 0.1e6 -32.5 0.25e6 -33.5 1.104e6 -33.5 1.5e6 -49.5 2.5e6 -74.0 4.47e6 -104.0 10.0e6 -104.0 30.0e6 -104.0],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream='calcPSD([1 -24.5 0.03e6 -25.0 0.065e6 -31.0 0.13e6 -31.0 0.25e6 -49.0 0.4e6 -78.0 0.65e6 -81.5 1.104e6 -81.5 1.4e6 -83.0 2.75e6 -103.5 4.0e6 -104.0 10.0e6 -104.0 30.0e6 -104.0],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

%=== oldplan A
tmp_tfplan=def_tfplan;
tmp_tfplan.name='ANSI-VDSL-NoiseA-old';
tmp_tfplan.PSD.downstream='calcPSD([1 -24.5 50e3 -32.0 100e3 -40.0 200e3 -46.0 400e3 -49.5 550e3 -52.5 1104e3 -60.5 1500e3 -75.0 2500e3 -109.5 3200e3 -132.5 4000e3 -140.0 10000e3 -140.0 30000e3 -140.0],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream='calcPSD([1 -23.0 50e3 -23.0 100e3 -29.0 200e3 -40.5 400e3 -78.0 550e3 -80.0 1104e3 -82.0 1500e3 -84.0 2500e3 -97.5 3200e3 -103.5 4500e3 -104.0 10000e3 -104.0 30000e3 -104.0],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);
