function clist = etsi_cablesADSL_extra(clist)
%% ===========================================================================
%etsi_cablesADSL_extra(clist) - Sets up the cable models for ETSI
%
% Parameter:    clist          Structure describing the cables
% Returns:      clist          Structure describing the cables
%
% Example(s):
%   ex.clist = etsi_cablesADSL_extra(ex.clist);        Add to existing clist
%   cableparam = getList(ex.clist,'ETSI-ADSL-PE032');  Get a PE 0.32 ADSL cable
%
%   ex.clist = etsi_cablesADSL_extra([]);              Create a new clist
%   cableparam = getList(ex.clist,'ETSI-ADSL-PE05');   Get a PE 0.5 ADSL cable
%
% Reference:
%   ETSI STC TM6 RTS/TM-06025 rev1a 2001-09
%   ETSI STC TM6 PD 980p10a5 "Laboratory Performance tests for xDSL
%   systems" (feb 5, 2001)
%   Draft ITU-T Recommendation G.996.1 "Test procedures for DSL tranceivers"
%   ETSI TM6 021t32, Torino, Italy, 4th-8th Feb., 2002.
%   ETSI STC TM6 DTS/TM-06018 (Draft m00p10a5NC) 2001-03
%% ===========================================================================

%% ===========================================================================
% Copyright (C):                                        
%       2000-2009 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%
% CVS:       $Id: etsi_cablesADSL_extra.m 752 2009-01-02 13:03:52Z tono $
%% ===========================================================================
% Change History
%      2000-07-19 (ToNo) Changed so that r0s can be zero for BT models
%      2001-07-04 (ToNo) Added cable models used in ADSL simulations
%      2002-01-11 (ToNo) Added ETSI ADSL as param. models from ETSI 981t08a1
%      2002-01-12 (ToNo) Added ETSI ADSL as param. models from ITU 996.1
%      2002-01-27 (ToNo) Added ETSI ADSL as param. models MAR2 models
%      2002-02-01 (ToNo) Updated  the original ETSI ADSL parameters
%      2002-03-12 (ToNo) Updated the ETSI ADSL mar2 models suggested by ftw 
%      2002-08-23 (ToNo) Split up according to technology
%% ===========================================================================


%% ===========================================================================
% ETSI ADSL as models from ITU 996.1

cable=[];
cable.name='ETSI-ADSL-PE032i';
cable.model='BT';

cable.param.r0c = .409e3;    
cable.param.r0s = 0;
cable.param.ac  = .3822;
cable.param.as  = 0;
cable.param.l0  = 0.6075e-3;
cable.param.loo = 0.5e-3; 
cable.param.b   = 5.269;     
cable.param.fm  = .609e6;    
cable.param.coo = 40e-9;
cable.param.c0  = 0;
cable.param.ce  = 0;
cable.param.g0  = 0;
cable.param.ge  = 1;
clist=insertList(clist,cable);

cable=[];
cable.name='ETSI-ADSL-PE04i';
cable.model='BT';

cable.param.r0c = .28e3;    
cable.param.r0s = 0;
cable.param.ac  = .0969;
cable.param.as  = 0;
cable.param.l0  = 0.5873e-3;
cable.param.loo = 0.4260e-3; 
cable.param.b   = 1.385;     
cable.param.fm  = .7459e6;    
cable.param.coo = 50e-9;
cable.param.c0  = 0;
cable.param.ce  = 0;
cable.param.g0  = 0;
cable.param.ge  = 1;
clist=insertList(clist,cable);

cable=[];
cable.name='ETSI-ADSL-PE05i';
cable.model='BT';

cable.param.r0c = .1792e3;    
cable.param.r0s = 0;
cable.param.ac  = .0561;
cable.param.as  = 0;
cable.param.l0  = 0.6746e-3;
cable.param.loo = 0.5327e-3; 
cable.param.b   = 1.195;     
cable.param.fm  = .6647e6;    
cable.param.coo = 50e-9;
cable.param.c0  = 0;
cable.param.ce  = 0;
cable.param.g0  = 0;
cable.param.ge  = 1;
clist=insertList(clist,cable);

cable=[];
cable.name='ETSI-ADSL-PE063i';
cable.model='BT';

cable.param.r0c = .113e3;    
cable.param.r0s = 0;
cable.param.ac  = .0257;
cable.param.as  = 0;
cable.param.l0  = 0.6994e-3;
cable.param.loo = 0.4772e-3; 
cable.param.b   = 1.0956;     
cable.param.fm  = .2658e6;    
cable.param.coo = 45e-9;
cable.param.c0  = 0;
cable.param.ce  = 0;
cable.param.g0  = 0;
cable.param.ge  = 1;
clist=insertList(clist,cable);

cable=[];
cable.name='ETSI-ADSL-PE09i';
cable.model='BT';

cable.param.r0c = .0551e3;    
cable.param.r0s = 0;
cable.param.ac  = .0094;
cable.param.as  = 0;
cable.param.l0  = 0.7509e-3;
cable.param.loo = 0.5205e-3; 
cable.param.b   = 0.9604;     
cable.param.fm  = .1238e6;    
cable.param.coo = 40e-9;
cable.param.c0  = 0;
cable.param.ce  = 0;
cable.param.g0  = 0;
cable.param.ge  = 1;
clist=insertList(clist,cable);

%% ===========================================================================
% ETSI ADSL as MAR2 models, curve fitting with above models 
% Ref: ETSI TM6 021t32, Torino, Italy, 4th-8th Feb., 2002.

cable=[];
cable.name='ETSI-ADSL-PE032mar';
cable.model='MAR2';

% vars = [400.666842 411.961536e-6 2.156655 39.639546e-9 0.002840]; % optimized
vars = [409 0.00040 2.05 4e-08 0 ]; % handmade

cable.param.R0     = vars(1);      % Roo/km
cable.param.Linf   = vars(2);      % Linf/km
cable.param.a      = vars(3);      % (proximity factor)
cable.param.C1M    = vars(4);      % Cp/km(@1MHz)
cable.param.delta  = vars(5);      % Delta(constant)
clist=insertList(clist,cable);


cable=[];
cable.name='ETSI-ADSL-PE04mar';
cable.model='MAR2';

% vars = [277.623806 421.576013e-6 1.470148 49.792437e-9 0.001123 ]; % optimized
vars = [280 0.0004 1.44 5e-08 0 ]; % handmade

cable.param.R0     = vars(1);      % Roo/km
cable.param.Linf   = vars(2);      % Linf/km
cable.param.a      = vars(3);      % (proximity factor)
cable.param.C1M    = vars(4);      % Cp/km(@1MHz)
cable.param.delta  = vars(5);      % Delta(constant)
clist=insertList(clist,cable);


cable=[];
cable.name='ETSI-ADSL-PE05mar';
cable.model='MAR2';

% vars = [179.460137 516.017173e-6 1.705113 49.840489e-9 0.002647 ]; % optimized
vars = [179     0.0005 1.79 5e-08 0 ]; % handmade

cable.param.R0     = vars(1);      % Roo/km
cable.param.Linf   = vars(2);      % Linf/km
cable.param.a      = vars(3);      % (proximity factor)
cable.param.C1M    = vars(4);      % Cp/km(@1MHz)
cable.param.delta  = vars(5);      % Delta(constant)
clist=insertList(clist,cable);


cable=[];
cable.name='ETSI-ADSL-PE063mar';
cable.model='MAR2';

% vars = [111.100648 471.310664e-6 1.948990 44.685737e-9 0.003210]; % optimized
vars = [113     0.00045 2.01 4.5e-08 0 ]; % handmade


cable.param.R0     = vars(1);      % Roo/km
cable.param.Linf   = vars(2);      % Linf/km
cable.param.a      = vars(3);      % (proximity factor)
cable.param.C1M    = vars(4);      % Cp/km(@1MHz)
cable.param.delta  = vars(5);      % Delta(constant)
clist=insertList(clist,cable);


cable=[];
cable.name='ETSI-ADSL-PE09mar';
cable.model='MAR2';


%vars = [54.753441 502.965928e-6 2.446506 39.855129e-9 0.002673]; % optimized
vars = [55 0.0005 2.56 4e-08 0 ]; % handmade

cable.param.R0     = vars(1);      % Roo/km
cable.param.Linf   = vars(2);      % Linf/km
cable.param.a      = vars(3);      % (proximity factor)
cable.param.C1M    = vars(4);      % Cp/km(@1MHz)
cable.param.delta  = vars(5);      % Delta(constant)

clist=insertList(clist,cable);

%% ===========================================================================
% ETSI ADSL as MAR2 models, curve fitting with above models 
% Ref: ETSI TM6 021t32, Torino, Italy, 4th-8th Feb., 2002.

cable=[];
cable.name='ETSI-ADSL-PE032maropt';
cable.model='MAR2';

vars = [400.666842 411.961536e-6 2.156655 39.639546e-9 0.002840]; % optimized

cable.param.R0     = vars(1);      % Roo/km
cable.param.Linf   = vars(2);      % Linf/km
cable.param.a      = vars(3);      % (proximity factor)
cable.param.C1M    = vars(4);      % Cp/km(@1MHz)
cable.param.delta  = vars(5);      % Delta(constant)
clist=insertList(clist,cable);


cable=[];
cable.name='ETSI-ADSL-PE04maropt';
cable.model='MAR2';

vars = [277.623806 421.576013e-6 1.470148 49.792437e-9 0.001123 ]; % optimized

cable.param.R0     = vars(1);      % Roo/km
cable.param.Linf   = vars(2);      % Linf/km
cable.param.a      = vars(3);      % (proximity factor)
cable.param.C1M    = vars(4);      % Cp/km(@1MHz)
cable.param.delta  = vars(5);      % Delta(constant)
clist=insertList(clist,cable);


cable=[];
cable.name='ETSI-ADSL-PE05maropt';
cable.model='MAR2';

vars = [179.460137 516.017173e-6 1.705113 49.840489e-9 0.002647 ]; % optimized

cable.param.R0     = vars(1);      % Roo/km
cable.param.Linf   = vars(2);      % Linf/km
cable.param.a      = vars(3);      % (proximity factor)
cable.param.C1M    = vars(4);      % Cp/km(@1MHz)
cable.param.delta  = vars(5);      % Delta(constant)
clist=insertList(clist,cable);


cable=[];
cable.name='ETSI-ADSL-PE063maropt';
cable.model='MAR2';

vars = [111.100648 471.310664e-6 1.948990 44.685737e-9 0.003210]; % optimized


cable.param.R0     = vars(1);      % Roo/km
cable.param.Linf   = vars(2);      % Linf/km
cable.param.a      = vars(3);      % (proximity factor)
cable.param.C1M    = vars(4);      % Cp/km(@1MHz)
cable.param.delta  = vars(5);      % Delta(constant)
clist=insertList(clist,cable);


cable=[];
cable.name='ETSI-ADSL-PE09maropt';
cable.model='MAR2';


vars = [54.753441 502.965928e-6 2.446506 39.855129e-9 0.002673]; % optimized

cable.param.R0     = vars(1);      % Roo/km
cable.param.Linf   = vars(2);      % Linf/km
cable.param.a      = vars(3);      % (proximity factor)
cable.param.C1M    = vars(4);      % Cp/km(@1MHz)
cable.param.delta  = vars(5);      % Delta(constant)

clist=insertList(clist,cable);
