function clist = etsi_cablesVDSL(clist)
%% ===========================================================================
%etsi_cablesVDSL(clist) - Sets up the cable models for ETSI
%
% Parameter:    clist          Structure describing the cables
% Returns:      clist          Structure describing the cables
%
% Example(s):
%   ex.clist = etsi_cablesVDSL(ex.clist);            Add to existing clist
%   cableparam = getList(ex.clist,'BT_dwug');    Get BT dwug cable
%
%   ex.clist = etsi_cablesVDSL([]);                  Create a new clist
%   cableparam = getList(ex.clist,'DTAG_04');    Get DTAG 4mm cable
%
% Reference:
%   ETSI STC "Cable reference models for simulating metallic
%   access networks", 970p02r3 TM6(97)02 (version 01-07-98)
%   ETSI STC TM6 Helsinki 2000 TD18
%   ETSI STC TM6 PD 980p10a5 "Laboratory Performance tests for xDSL
%   systems" (feb 5, 2001)
%   Draft ITU-T Recommendation G.996.1 "Test procedures for DSL tranceivers"
%   W. Henkel, et al. "Update of cable reference models", 
%   ETSI Contribution 985t04c0, Sopha Antipolis, France, Nov 24-27, 1998
%   ETSI STC TM6 RTS/TM-06025 rev1a 2001-09
%   ETSI STC TM6 021t32, Torino, Italy, 4th-8th Feb., 2002.
%   ETSI STC TM6 DTS/TM-06018 (Draft m00p10a5NC) 2001-03
%   ETSI STC TM6 "Cable reference models for simulating metallic
%   access networks", 970p02r3
%% ===========================================================================

%% ===========================================================================
% Copyright (C):                                        
%       1998-1999 by Telia Research AB, Lulea, Sweden;                
%       2000-2009 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%
% CVS:       $Id: etsi_cablesVDSL.m 752 2009-01-02 13:03:52Z tono $
%% ===========================================================================
% Change History
%      1998-01-05 (Dab)  Moved to this project
%      1998-01-07 (ToNo) Added header and comments
%      1999-02-08 (DaB)  Fixed index bug in DTAG06 cable
%      1999-06-18 (ToNo) Removed one of the operators cables
%      2000-03-14 (ToNo) Moved cable defs. into xdsldefs and did the list thing
%      2000-07-18 (ToNo) Corrected the tan_fi values for KPN cables
%      2000-07-19 (ToNo) Changed so that r0s can be zero for BT models
%      2001-12-20 (ToNo) Added the modified DTAG model
%      2002-08-23 (ToNo) Split up according to technology
%      2005-05-13 (ToNo) Split out ANSI VDSL cables into its own file
%      2005-10-31 (ToNo) Added FT and Swisscom cable models
%% ===========================================================================

c0 = 299792458; % speed of light (used in KPN model definitions)

%% ===========================================================================
% Finnish (Nokia) cables

% 0.4 mm
cable=[];
cable.name='NOK_40';
cable.model='BT';
cable.param.r0c=271.9983;
cable.param.r0s=0;
cable.param.ac=0.07960468;
cable.param.as=0;
cable.param.l0=710.7494e-6;
cable.param.loo=590.0163e-6;
cable.param.b=1.229532;
cable.param.fm=1.0300517e6;
cable.param.coo=38.6e-9;
cable.param.c0=0;
cable.param.ce=0;
cable.param.g0=1.100869e-9;
cable.param.ge=0.999424;
clist=insertList(clist,cable);

% 0.5 mm
cable=[];
cable.name='NOK_50';
cable.model='BT';
cable.param.r0c=173.99847;
cable.param.r0s=0;
cable.param.ac=0.0322326;
cable.param.as=0;
cable.param.l0=707.45088e-6;
cable.param.loo=581.5551e-6;
cable.param.b=1.095304;
cable.param.fm=693.804e3;
cable.param.coo=38.9e-9;
cable.param.c0=0;
cable.param.ce=0;
cable.param.g0=0.5007629e-9;
cable.param.ge=1.04681;
clist=insertList(clist,cable);

%% ===========================================================================
% British Telecom cables

% dw1 Single Pair 0.91 mm cadmium-copper conductor PVC insulated 
cable=[];
cable.name='BT_dw1';
cable.model='BT';
cable.param.r0c=65.32;
cable.param.r0s=0;
cable.param.ac=2.715283e-3;
cable.param.as=0;
cable.param.l0=0.884242e-3;
cable.param.loo=800.587e-6;
cable.param.b=1.30698;
cable.param.fm=263371;
cable.param.coo=28.0166e-9;
cable.param.c0=46.5668e-9;
cable.param.ce=0.117439;
cable.param.g0=855e-9;
cable.param.ge=0.746;
clist=insertList(clist,cable);

% dw3 Single Pair 0.72 mm copper coverd steel PVC insulated
cable=[];
cable.name='BT_dw3';
cable.model='BT';
cable.param.r0c=335.180;
cable.param.r0s=1281.3;
cable.param.ac=5.35389e-3;
cable.param.as=30286.34;
cable.param.l0=1.14166e-3;
cable.param.loo=708.221e-6;
cable.param.b=1.12676;
cable.param.fm=15211;
cable.param.coo=24.446503e-9;
cable.param.c0=34.431082e-9;
cable.param.ce=0.06589;
cable.param.g0=137.182e-9;
cable.param.ge=0.807645;
clist=insertList(clist,cable);

% dw5
cable=[];
cable.name='BT_dw5';
cable.model='BT';
cable.param.r0c=335.321;
cable.param.r0s=1116.45012;
cable.param.ac=10.996373e-3;
cable.param.as=13175.463;
cable.param.l0=1.13771e-3;
cable.param.loo=792.766e-6;
cable.param.b=1.52968;
cable.param.fm=20842.6;
cable.param.coo=29.297887e-9;
cable.param.c0=31.60789e-9;
cable.param.ce=0.1115489;
cable.param.g0=32.574128e-9;
cable.param.ge=0.919;
clist=insertList(clist,cable);

% dw6 Single Pair 0.81 mm copper covered steel conductor PVC insulated 
cable=[];
cable.name='BT_dw6';
cable.model='BT';
cable.param.r0c=270.70256;
cable.param.r0s=774.23224;
cable.param.ac=2.48956e-3;
cable.param.as=3349.76;
cable.param.l0=1.10646e-3;
cable.param.loo=760.267e-6;
cable.param.b=1.35790;
cable.param.fm=15668;
cable.param.coo=27.8941e-9;
cable.param.c0=39.4114e-9;
cable.param.ce=0.106593;
cable.param.g0=360e-9;
cable.param.ge=0.777;
clist=insertList(clist,cable);

% dw8 Single Pair flat twin 1.14 mm cadmium-copper conductor PVC insulated 
cable=[];
cable.name='BT_dw8';
cable.model='BT';
cable.param.r0c=41.16;
cable.param.r0s=0;
cable.param.ac=1.2179771e-3;
cable.param.as=0;
cable.param.l0=1e-3;
cable.param.loo=910.505e-6;
cable.param.b=1.1952665;
cable.param.fm=174877;
cable.param.coo=22.681213e-9;
cable.param.c0=31.778569e-9;
cable.param.ce=0.11086674;
cable.param.g0=53e-9;
cable.param.ge=0.88;
clist=insertList(clist,cable);

% dw10 2 Pair 0.5 mm copper conductor PVC ins. PVC ins. steel Polyeth. sheath 
cable=[];
cable.name='BT_dw10';
cable.model='BT';
cable.param.r0c=180.93;
cable.param.r0s=0;
cable.param.ac=0.0497223;
cable.param.as=0;
cable.param.l0=728.8683e-6;
cable.param.loo=543.4352e-6;
cable.param.b=0.75577086;
cable.param.fm=718888;
cable.param.coo=50.928328e-9;
cable.param.c0=63.824345e-9;
cable.param.ce=0.11584622;
cable.param.g0=89.041038e-9;
cable.param.ge=0.85606301;
clist=insertList(clist,cable);

% dw12 Single Pair 0.9 mm copper conductor Pol.ins. PVC cov. steel Pol.sheath  
cable=[];
cable.name='BT_dw12';
cable.model='BT';
cable.param.r0c=55.460555;
cable.param.r0s=0;
cable.param.ac=4.9924627e-3;
cable.param.as=0;
cable.param.l0=0.62104396e-3;
cable.param.loo=461.954e-6;
cable.param.b=0.93970931;
cable.param.fm=193049;
cable.param.coo=51.128076e-9;
cable.param.c0=5.802245e-9;
cable.param.ce=0.10064577;
cable.param.g0=20e-9;
cable.param.ge=0.88;
clist=insertList(clist,cable);

% dwug mult pair 0.5 mm copper Poly. ins. Underground dist.
cable=[];
cable.name='BT_dwug';
cable.model='BT';
cable.param.r0c=179;
cable.param.r0s=0;
cable.param.ac=35.89e-3;
cable.param.as=0;
cable.param.l0=0.695e-3;
cable.param.loo=585e-6;
cable.param.b=1.2;
cable.param.fm=1e6;
cable.param.coo=55e-9;
cable.param.c0=1e-9;
cable.param.ce=0.1;
cable.param.g0=0.5e-9;
cable.param.ge=1.033;
clist=insertList(clist,cable);


%% ===========================================================================
% Original Deutsche Telekom AG cables

% 0.35 mm
cable=[];
cable.name='DTAG_35o';
cable.model='DTAGorg';
cable.param.Ka1=[9.4 2.4 15.9];
cable.param.Ka2=[13.2 19.9 11.2];
cable.param.Ka3=[0.97 0.54 0.69];
cable.param.Kb1=34.2;
cable.param.Kb2=2.62;
cable.param.Kz1=132;
cable.param.Kz2=5;
cable.param.Kz3=0.73;
cable.param.Kx1=0.05;
cable.param.Kx2=0.024;
cable.param.Kx3=0.87;
clist=insertList(clist,cable);

% 0.40 mm
cable=[];
cable.name='DTAG_40o';
cable.model='DTAGorg';
cable.param.Ka1=[6.9 0.3 10.4];
cable.param.Ka2=[13.4 18.9 11.5];
cable.param.Ka3=[0.99 0.5 0.64];
cable.param.Kb1=32.9;
cable.param.Kb2=2.26;
cable.param.Kz1=127;
cable.param.Kz2=8.8;
cable.param.Kz3=0.51;
cable.param.Kx1=0.045;
cable.param.Kx2=0.016;
cable.param.Kx3=0.81;
clist=insertList(clist,cable);

% 0.50 mm
cable=[];
cable.name='DTAG_50o';
cable.model='DTAGorg';
cable.param.Ka1=[4.2 0.7 10.3];
cable.param.Ka2=[11.9 14.1 7.7];
cable.param.Ka3=[0.92 0.52 0.68];
cable.param.Kb1=30.6;
cable.param.Kb2=1.62;
cable.param.Kz1=141;
cable.param.Kz2=3.4;
cable.param.Kz3=0.69;
cable.param.Kx1=0.038;
cable.param.Kx2=0.0082;
cable.param.Kx3=0.73;
clist=insertList(clist,cable);

% 0.60 mm
cable=[];
cable.name='DTAG_60o';
cable.model='DTAGorg';
cable.param.Ka1=[2.4 1.1 8.7];
cable.param.Ka2=[11.2 11.6 6.6];
cable.param.Ka3=[0.75 0.54 0.69];
cable.param.Kb1=30.4;
cable.param.Kb2=1.62;
cable.param.Kz1=135;
cable.param.Kz2=3.4;
cable.param.Kz3=0.63;
cable.param.Kx1=0.036;
cable.param.Kx2=0.0038;
cable.param.Kx3=0.64;
clist=insertList(clist,cable);

%% ===========================================================================
% Updated Deutsche Telekom AG cables
%   W. Henkel, et al. "Update of cable reference models", 
%   ETSI Contribution 985t04c0, Sopha Antipolis, France, Nov 24-27, 1998

% 0.35 mm
cable=[];
cable.name='DTAG_35';
cable.model='DTAG';
cable.param.Ka1=[9.4 2.4 15.9];
cable.param.Ka2=[13.2 19.9 11.2];
cable.param.Ka3=[0.97 0.54 0.69];
cable.param.Kb1=[35.06, 33.96, 34.13];
cable.param.Kb2=[1.725, 2.700, 2.458];
cable.param.Kb3=[0.545, 0.585, 0.560];
cable.param.Kz1=132;
cable.param.Kz2=5;
cable.param.Kz3=0.73;
cable.param.Kx1=0.05;
cable.param.Kx2=0.024;
cable.param.Kx3=0.87;
clist=insertList(clist,cable);

% 0.40 mm
cable=[];
cable.name='DTAG_40';
cable.model='DTAG';
cable.param.Ka1=[6.9 0.3 10.4];
cable.param.Ka2=[13.4 18.9 11.5];
cable.param.Ka3=[0.99 0.5 0.64];
cable.param.Kb1=[33.47, 32.82, 32.87];
cable.param.Kb2=[1.782, 2.229, 2.113];
cable.param.Kb3=[0.601, 0.543, 0.543];
cable.param.Kz1=127;
cable.param.Kz2=8.8;
cable.param.Kz3=0.51;
cable.param.Kx1=0.045;
cable.param.Kx2=0.016;
cable.param.Kx3=0.81;
clist=insertList(clist,cable);

% 0.50 mm
cable=[];
cable.name='DTAG_50';
cable.model='DTAG';
cable.param.Ka1=[4.2 0.7 10.3];
cable.param.Ka2=[11.9 14.1 7.7];
cable.param.Ka3=[0.92 0.52 0.68];
cable.param.Kb1=[29.45, 30.53, 30.57];
cable.param.Kb2=[2.899, 1.728, 1.676];
cable.param.Kb3=[0.739, 0.529, 0.516];
cable.param.Kz1=141;
cable.param.Kz2=3.4;
cable.param.Kz3=0.69;
cable.param.Kx1=0.038;
cable.param.Kx2=0.0082;
cable.param.Kx3=0.73;
clist=insertList(clist,cable);

% 0.60 mm
cable=[];
cable.name='DTAG_60';
cable.model='DTAG';
cable.param.Ka1=[2.4 1.1 8.7];
cable.param.Ka2=[11.2 11.6 6.6];
cable.param.Ka3=[0.75 0.54 0.69];
cable.param.Kb1=[28.94, 30.43, 30.43];
cable.param.Kb2=[2.950, 1.459, 1.449];
cable.param.Kb3=[0.736, 0.508, 0.509];
cable.param.Kz1=135;
cable.param.Kz2=3.4;
cable.param.Kz3=0.63;
cable.param.Kx1=0.036;
cable.param.Kx2=0.0038;
cable.param.Kx3=0.64;
clist=insertList(clist,cable);

%% ===========================================================================
% Royal Dutch Telecom (KPN) cables

% KPN_L1
cable=[];
cable.name='KPN_L1';
cable.model='KPN';
cable.param.Z0oo=136.651;
cable.param.c=0.79766*c0;
cable.param.Rss00=0.168145;
cable.param.tan_fi=0.13115/(2*pi);
cable.param.Kf=0.72;
cable.param.K1=1.2;
cable.param.Kn=1;
cable.param.Kc=1.08258;
cable.param.N=0.7;
cable.param.fc0=4521710;
cable.param.M=1;
clist=insertList(clist,cable);

% KPN_L2
cable=[];
cable.name='KPN_L2';
cable.model='KPN';
cable.param.Z0oo=136.047;
cable.param.c=0.798958*c0;
cable.param.Rss00=0.168145;
cable.param.tan_fi=0.16998/(2*pi);
cable.param.Kf=0.7;
cable.param.K1=1.1;
cable.param.Kn=1;
cable.param.Kc=1.08201;
cable.param.N=1;
cable.param.fc0=1862950;
cable.param.M=1;
clist=insertList(clist,cable);

% KPN_L3
cable=[];
cable.name='KPN_L3';
cable.model='KPN';
cable.param.Z0oo=137.527;
cable.param.c=0.850608*c0;
cable.param.Rss00=0.065682;
cable.param.tan_fi=0.114526/(2*pi);
cable.param.Kf=1;
cable.param.K1=1;
cable.param.Kn=1;
cable.param.Kc=1.06967;
cable.param.N=1;
cable.param.fc0=559844;
cable.param.M=1;
clist=insertList(clist,cable);

% KPN_L4
cable=[];
cable.name='KPN_L4';
cable.model='KPN';
cable.param.Z0oo=137.005;
cable.param.c=0.787661*c0;
cable.param.Rss00=0.168145;
cable.param.tan_fi=0.153522/(2*pi);
cable.param.Kf=0.9;
cable.param.K1=1;
cable.param.Kn=1;
cable.param.Kc=1.07478;
cable.param.N=1;
cable.param.fc0=557458;
cable.param.M=1;
clist=insertList(clist,cable);

% KPN_H1
cable=[];
cable.name='KPN_H1';
cable.model='KPN';
cable.param.Z0oo=135.458;
cable.param.c=0.640381*c0;
cable.param.Rss00=0.177728;
cable.param.tan_fi=0.018425/(2*pi);
cable.param.Kf=0.85;
cable.param.K1=1;
cable.param.Kn=1;
cable.param.Kc=1.11367;
cable.param.N=1.5;
cable.param.fc0=5020;
cable.param.M=1;
clist=insertList(clist,cable);

% KPN_KK
cable=[];
cable.name='KPN_KK';
cable.model='KPN';
cable.param.Z0oo=142.451;
cable.param.c=0.712318*c0;
cable.param.Rss00=0.177728;
cable.param.tan_fi=0.071111/(2*pi);
cable.param.Kf=0.8;
cable.param.K1=1.1;
cable.param.Kn=1;
cable.param.Kc=1.09373;
cable.param.N=0.5;
cable.param.fc0=8088;
cable.param.M=1;
clist=insertList(clist,cable);

% KPN_R2
cable=[];
cable.name='KPN_R2';
cable.model='KPN';
cable.param.Z0oo=97.4969;
cable.param.c=0.639405*c0;
cable.param.Rss00=0.177728;
cable.param.tan_fi=0.0189898/(2*pi);
cable.param.Kf=0.5;
cable.param.K1=1.14;
cable.param.Kn=1;
cable.param.Kc=1;
cable.param.N=1;
cable.param.fc0=100000;
cable.param.M=1;
clist=insertList(clist,cable);

%% ===========================================================================
% French Telecom cables
%   Taken from: ETSI STC "Cable reference models for simulating metallic
%   access networks", 970p02r3 TM6(97)02 (version 01-07-98)

%FT_dw1 37.795 0.079 0.0 0.0 1e-3 0.84e-3 674800
%0.716 9.097e-9 0.946 1.644e-7 2.327e-8 0.564
cable=[];
cable.name='FT_dw1';
cable.model='BT';
cable.param.r0c=37.795;
cable.param.ac=0.079;
cable.param.r0s=0;
cable.param.as=0;
cable.param.l0=1e-3;
cable.param.loo=0.84e-3;
cable.param.fm=674800;
cable.param.b=0.716;
cable.param.g0=9.097e-9;
cable.param.ge= 0.946;
cable.param.c0=1.644e-7;
cable.param.coo=2.327e-8;
cable.param.ce= 0.564;
clist=insertList(clist,cable);

%FT_dw2 60.874 0.01 0.0 0.0 0.72e-3 0.53e-3 327800
%0.665 1.101e-8 1.014 1.288e-5 4.642e-8 0.924
cable=[];
cable.name='FT_dw2';
cable.model='BT';
cable.param.r0c=60.874;
cable.param.ac=0.01;
cable.param.r0s=0;
cable.param.as=0;
cable.param.l0=0.72e-3;
cable.param.loo=0.53e-3;
cable.param.fm=327800;
cable.param.b=0.665;
cable.param.g0=1.101e-8;
cable.param.ge=1.014;
cable.param.c0=1.288e-5;
cable.param.coo=4.642e-8;
cable.param.ce=0.924;
clist=insertList(clist,cable);

%FT_dw3 118.719 0.026 0.0 0.0 0.61e-3 0.41e-3 392600
%0.805 9.4e-9 0.944 6.272e-6 6.58e-8 0.769
cable=[];
cable.name='FT_dw3';
cable.model='BT';
cable.param.r0c=118.719;
cable.param.ac=0.026;
cable.param.r0s=0;
cable.param.as=0;
cable.param.l0=0.61e-3;
cable.param.loo=0.41e-3;
cable.param.fm=392600;
cable.param.b=0.805;
cable.param.g0=9.4e-9;
cable.param.ge=0.944;
cable.param.c0=6.272e-6;
cable.param.coo=6.58e-8;
cable.param.ce=0.769;
clist=insertList(clist,cable);

%FT_04 271.224 0.203 0.0 0.0 0.74e-3 0.501e-3 607100
%0.886 1.845e-14 1.57 6.365e-7 4.93e-8 0.599
cable=[];
cable.name='FT_04';
cable.model='BT';
cable.param.r0c=271.224;
cable.param.ac=0.203;
cable.param.r0s=0;
cable.param.as=0;
cable.param.l0=0.74e-3;
cable.param.loo=0.501e-3;
cable.param.fm=607100;
cable.param.b=0.886;
cable.param.g0=1.845e-14;
cable.param.ge=1.57;
cable.param.c0=6.365e-7;
cable.param.coo=4.93e-8;
cable.param.ce=0.599;
clist=insertList(clist,cable);

%FT_06 122.577 0.044 0.0 0.0 0.72e-3 0.48e-3 331600
%0.786 3.033e-10 1.095 1.581e-6 4.852e-8 0.683
cable=[];
cable.name='FT_06';
cable.model='BT';
cable.param.r0c=122.577;
cable.param.ac=0.044;
cable.param.r0s=0;
cable.param.as=0;
cable.param.l0=0.72e-3;
cable.param.loo=0.48e-3;
cable.param.fm=331600;
cable.param.b=0.786;
cable.param.g0=3.033e-10;
cable.param.ge=1.095;
cable.param.c0=1.581e-6;
cable.param.coo=4.852e-8;
cable.param.ce= 0.683;
clist=insertList(clist,cable);

%FT_08 65.804 0.012 0.0 0.0 0.74e-3 0.51e-3 180800
%0.756 2.92e-7 0.606 8.998e-7 4.479e-8 0.626
cable=[];
cable.name='FT_08';
cable.model='BT';
cable.param.r0c=65.804;
cable.param.ac=0.012;
cable.param.r0s=0;
cable.param.as=0;
cable.param.l0=0.74e-3;
cable.param.loo=0.51e-3;
cable.param.fm=180800;
cable.param.b=0.756;
cable.param.g0=2.92e-7;
cable.param.ge=0.606;
cable.param.c0=8.998e-7;
cable.param.coo=4.479e-8;
cable.param.ce=0.626;
clist=insertList(clist,cable);


%% ===========================================================================
% Swisscom cables
%   Taken from: ETSI STC "Cable reference models for simulating metallic
%   access networks", 970p02r3 TM6(97)02 (version 01-07-98)

% SWC_40 135 45000 44000 13000 250000 24500 0.59 0.65 0.475 0.51 0.44 0.007 0.043
cable=[];
cable.name='SWC_40';
cable.model='SWC';
cable.param.Z00=135;
cable.param.f1=45000;
cable.param.f2=44000;
cable.param.f3=13000;
cable.param.f4=250000;
cable.param.f5=24500;
cable.param.Ne1=0.59;
cable.param.Ne2=0.65;
cable.param.Ne3=0.475;
cable.param.Ne4=0.51;
cable.param.C1=0.44;
cable.param.C2=0.007;
cable.param.C3=0.043;
clist=insertList(clist,cable);

%SWC_60 135 13000 21000 7500 125000 12500 0.75 0.65 0.475 0.51 0.46 0.0037 0.022
cable=[];
cable.name='SWC_60';
cable.model='SWC';
cable.param.Z00=135;
cable.param.f1=13000;
cable.param.f2=21000;
cable.param.f3=7500;
cable.param.f4=125000;
cable.param.f5=12500;
cable.param.Ne1=0.75;
cable.param.Ne2=0.65;
cable.param.Ne3=0.475;
cable.param.Ne4=0.51;
cable.param.C1=0.46;
cable.param.C2=0.0037;
cable.param.C3=0.022;
clist=insertList(clist,cable);


%% ===========================================================================
%  Define some commonly used aliases

cable=getList(clist,'BT_dwug');
cable.name='ETSI';
clist=insertList(clist,cable);

cable=getList(clist,'BT_dwug');
cable.name='TP100';
clist=insertList(clist,cable);

cable=getList(clist,'BT_dw8');
cable.name='TP180x';
clist=insertList(clist,cable);

cable=getList(clist,'KPN_L1');
cable.name='TP150';
clist=insertList(clist,cable);

cable=getList(clist,'KPN_R2');
cable.name='TP100x';
clist=insertList(clist,cable);
