function lclist = etsi_lcdefsVDSL(lclist)
%% ===========================================================================
%etsi_lcdefsVDSL(lclist) - Sets up the tfplan for ETSI HAM band
%
% Parameter:    lclist	        Structure describing line code dependent stuff
% Returns:      lclist		Structure describing line code dependent stuff
%
% Example(s):
%   ex.lclist = etsi_lcdefsVDSL(ex.lclist);            Add to existing lclist
%   lc = getList(ex.lclist,'VDSL-SCM');                Get SCM line code stuff
%
%   ex.lclist = etsi_lcdefsVDSL([]);                   Create a new lclist
%   lc = getList(ex.lclist,'VDSL-DMT-E1');             Get DMT line code stuff
%
% Reference:
%   ETSI VDSL TM-06003-2 V0.0.5 (1999-06)
%
%   ETSI TR 101 830-2,  Spectral management on metallic access
%   networks; Part 2: Technical  methods and performance
%   evaluations, m01p20a5
%% ===========================================================================

%% ===========================================================================
% Copyright (C):
%       1999 by Telia Research AB, Lulea, Sweden;
%       2000-2009 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%
% CVS:       $Id: etsi_lcdefsVDSL.m 752 2009-01-02 13:03:52Z tono $
%% ===========================================================================
% Change History
%      1999-10-25 (ToNo) Created
%      1999-11-04 (ToNo) Made it into a function
%      2003-11-28 (ToNo) Work on ETSI SpM started
%      2003-12-02 (ToNo) Added support for lc dependent modem noise
%      2005-01-12 (ToNo) Merged ETSI SpM work and made name changes
%      2008-09-22 (ToNo) Allow for empty lclist input again
%% ===========================================================================

% VDSL DMT params
tmp_lc=lcDefVDSLDMT;   %'VDSL-DMT'
lclist=insertList(lclist,tmp_lc);

% VDSL SCM params
tmp_lc=lcDefVDSLSCM;   %'VDSL-SCM'
lclist=insertList(lclist,tmp_lc);

%% ===========================================================================

% Start from VDSL theoretical
lcname = 'VDSL-theo'; % Defined in setupLClist.m
vix = searchList(lclist,lcname);
if length(vix) == 0,
    % Didn't call setupLClist before, do it now
    tmp_lclist = setupLClist();
    lclist = insertList(lclist,tmp_lclist{1});
    tmp_lc = tmp_lclist{1};
else
    tmp_lc=lclist{vix(1)};
end;

tmp_lc.name = 'ETSI-VDSL-theo';
tmp_lc.param.SNRMax         = 57;      % Maximum SNR available (dB)
tmp_lc.param.codingGain     = 3.8;     % To give 12dB Shannon gap
tmp_lc.param.SNRloss        = 2;
tmp_lc.param.alpha          = 0.2;
tmp_lc.param.guardBand      = 0;       % Defined by the PSD mask instead
tmp_lc.param.xtalk_margin   = 6;       % We use a cross-talk margin of 6dB
tmp_lc.param.signal_margin  = 0;       % (and therefore no signal margin)
tmp_lc.param.efficiencyLoss = 0.12;  
tmp_lc.param.PxDown         = 14.51;
tmp_lc.param.PxUp           = 11.5;

tmp_lc.param.modemNoise.LT  = '-140'; % Modem noise at LT (dBm/Hz)
tmp_lc.param.modemNoise.NT  = '-140'; % Modem noise at NT (dBm/Hz)

lclist = insertList(lclist,tmp_lc); 


%% ===========================================================================
% VDSL DMT params
def_lc=lcDefVDSLDMT;   %'VDSL-DMT'

def_lc.name = 'ETSI-VDSL-DMT';
def_lc.param.SNRMax         = 57;      % Maximum SNR available (dB)
def_lc.param.codingGain     = 3.8;     % To give 12dB Shannon gap
def_lc.param.SNRloss        = 2;
def_lc.param.alpha          = 0.2;
def_lc.param.guardBand      = 0;       % Defined by the PSD mask instead
def_lc.param.xtalk_margin   = 6;       % We use a cross-talk margin of 6dB
def_lc.param.signal_margin  = 0;       % (and therefore no signal margin)
def_lc.param.efficiencyLoss = 0;       
def_lc.param.PxDown         = 14.51;
def_lc.param.PxUp           = 11.5;

def_lc.param.modemNoise.LT  = '-140'; % Modem noise at LT (dBm/Hz)
def_lc.param.modemNoise.NT  = '-140'; % Modem noise at NT (dBm/Hz)

lclist=insertList(lclist,def_lc);

% NOTE that the following used tones do not necessarily correspond to
% what any real modem would use/allocate!

tmp_lc                      = def_lc;
tmp_lc.name                 = 'VDSL-DMT-E1';
% bandplan  = [138 3000 5100 7050 12000]*1e3; % 997
tmp_lc.param.dmt.us.tones    = [      699:1178        1638:2782];
tmp_lc.param.dmt.ds.tones    = [33:691       1186:1630];
lclist=insertList(lclist,tmp_lc);

tmp_lc                      = def_lc;
tmp_lc.name                 = 'VDSL-DMT-E2';
% bandplan  = [138 3750 5200 8500 12000]*1e3; % 998
tmp_lc.param.dmt.us.tones    = [      874:1200        1976:2782];
tmp_lc.param.dmt.ds.tones    = [33:865       1210:1966];
lclist=insertList(lclist,tmp_lc);

tmp_lc                      = def_lc;
tmp_lc.name                 = 'VDSL-DMT-E1U0';
% bandplan  = [25 138 3000 5100 7050 12000]*1e3; % 997 with US0
tmp_lc.param.dmt.us.tones    = [7:31      699:1178        1638:2782];
tmp_lc.param.dmt.ds.tones    = [    38:691       1186:1630];
lclist=insertList(lclist,tmp_lc);

tmp_lc                      = def_lc;
tmp_lc.name                 = 'VDSL-DMT-E2U0'; % 998 with US0
% bandplan  = [25 138 3750 5200 8500 12000]*1e3; % 998 with US0
tmp_lc.param.dmt.us.tones    = [7:31     874:1200        1976:2782];
tmp_lc.param.dmt.ds.tones    = [   38:865       1210:1966];
lclist=insertList(lclist,tmp_lc);

