function tfplist = etsi_tfplansESDSL(tfplist)
%% ===========================================================================
% etsi_tfplansESDSL(tfplist) - Sets up the tfplan for ETSI E-SDSL
%
% Parameter:    tfplist	   Structure describing the time and freq plan
% Returns:      tfplist	   Structure describing the time and freq plan
%
% Example(s):
%   ex.tfplist = etsi_tfplanESDSL(ex.tfplist);    Add to existing tfplist
%   tfplan=getList(ex.tfplist,'ESDSL-sym') ;      Get this ESDSL plan
%
%   ex.tfplist = etsi_tfplanESDSL([]);            Create a new tfplist
%   tfplan=getList(ex.tfplist,'ESDSL-sym');       Get this ESDSL plan
%
% References:	
%   Draft ETSI TS 101524-2 V1.1.1 (2000-05)
%
%   ETSI TR 101 830-2,  Spectral management on metallic access
%   networks; Part 2: Technical  methods and performance
%   evaluations, m01p20a5
%
%   ETSI TM6 034t06 ,034t07
%% ===========================================================================

%% ===========================================================================
% Copyright (C):
%       2004-2009 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.B.Nordstrom@Telia.se)
%
% CVS:       $Id: etsi_tfplansESDSL_SpM.m,v 1.2 2005/01/04 10:25:12 tono Exp $
%% ===========================================================================
% Change History
%      2004-01-09 (ToNo) Created
%% ===========================================================================


%% ===========================================================================
% Use a template, as order is important!

sdsl_tfplan = templateTFP;
    
% ESDSL generic default values
sdsl_tfplan.PSD.HAM.active        = 0;
sdsl_tfplan.PSD.active.upstream   = [5e3 4e6];
sdsl_tfplan.PSD.active.downstream = [5e3 4e6];
sdsl_tfplan.fixBitrate.name       = 'ESDSL';
sdsl_tfplan.fixBitrate.active     = 1;
sdsl_tfplan.fixBitrate.param      = [];


% ESDSL TFPlan defintions
% --------------------------

% Symmetric E-SDSL as specified in ETSI TM6 034t07
basic_tfplan=sdsl_tfplan;
basic_tfplan.name='ETSI-ESDSL-sym';
basic_tfplan.lcname='ETSI-ESDSL-sym';
basic_tfplan.PSD.downstream ='modelPSD_SDSL_sym_ver2(tfplan.lcname,ex.param.frequency.f)'; 
basic_tfplan.PSD.upstream   = basic_tfplan.PSD.downstream;	
basic_tfplan.PSD.UPBO.method='None'; 
tfplist=insertList(tfplist,basic_tfplan);


%% ===========================================================================
% Now set up some basic rates

% TCPAM-16

% brates = [2320 3840];
brates = [2320 2688 3072 3456 3840];

for brate = brates
    name = [basic_tfplan.name '16-' num2str(brate)];
    fsym=(brate+8)*1e3/3;
    tmp_tfplan= basic_tfplan;
    tmp_tfplan.PSD.active.upstream   = [1 2*fsym];
    tmp_tfplan.PSD.active.downstream = [1 2*fsym];
    tmp_tfplan.name=name;
    tmp_tfplan.lcname=name;
    tfplist=insertList(tfplist,tmp_tfplan);
end;

% TCPAM-32

% brates = [768 2680 2688 5696];
brates = [768 1152 1536 1920 2304 2680 2688 3072 3456 3840 4224 4608 4992 5696];

for brate = brates
    name = [basic_tfplan.name '32-' num2str(brate)];
    fsym=(brate+8)*1e3/3;
    tmp_tfplan= basic_tfplan;
    tmp_tfplan.PSD.active.upstream   = [1 2*fsym];
    tmp_tfplan.PSD.active.downstream = [1 2*fsym];
    tmp_tfplan.name=name;
    tmp_tfplan.lcname=name;
    tfplist=insertList(tfplist,tmp_tfplan);
end;
