function tfplist = fsan_modelsMISC(tfplist)
%% ===========================================================================
%fsan_modelsMISC(tfplist) - Sets up tfplans for some standard alien systems
%
% Parameter:    tfplist	        Structure describing the time and freq plan
% Returns:      tfplist		Structure describing the time and freq plan
%
% NOTE: This file contains more or less obsolete masks.
%       These masks where used for generation of noise profiles.
%       That is, these masks should not be used as reciever models
%       and the active frequencies are not always well defined.
%
% Example(s):
%   ex.tfplist = fsan_modelsMISC(ex.tfplist);    Add to existing tfplist
%   tfplan=getList(ex.tfplist,'NP-HDSL-2');          Get tfplan for HDSL 2
%
%   ex.tfplist = fsan_modelsMISC([]);            Create a new tfplist
%   tfplan=getList(ex.tfplist,'NP-ISDN-2B1Q');       Get tfplan for ISDN
%
% References:
%   ETSI VDSL Part 1 TS 101-270-1 V1.1.6 (1999-08)  
%   FSAN Noise model notebook, (J. Cook. c25.nb)
%   ETSI STC TM6(98)10 rev. 3 (nov. 26th, 1999)
%% ===========================================================================

%% ===========================================================================
% Copyright (C):                                        
%       1999-2000 by Telia Research AB, Lulea, Sweden;                
%       2000-2009 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%               : Gernot Schmid (Gernot.Schmid@arcs.ac.at)
%
% CVS:       $Id: fsan_modelsMISC.m 752 2009-01-02 13:03:52Z tono $
%% ===========================================================================
% Change History
%      1999-07-01 (Dab)  Created
%      1999-09-30 (DaB)  Rewritten for new ex struct
%      1999-10-25 (ToNo) Reorganized things into etsi,ansi,itu,fsan definitions
%      1999-11-04 (ToNo) Made it into a function
%      2000-01-19 (GS)   SDSL noise model extensions 
%      2000-04-05 (UvAn) Added frequency axis for the call to calcPSD
%      2005-05-10 (ToNo) Renamed these masks with a prefix NP (noise profile)
%% ===========================================================================

%% ===========================================================================
% Use a template, as order is important!

def_tfplan = templateTFP;

%% ===========================================================================
% TFPlan  definitions starting
% -------------------------------

% ADSL over POTS Reference  ETSI TD 20 Villach
tmp_tfplan=def_tfplan;
tmp_tfplan.name='NP-ADSL'; 
tmp_tfplan.PSD.downstream='calcPSD([.0001e6 -97.5 .00399e6 -97.5 .004e6 -92.5  .025875e6 -39.5 1.104e6 -39.5 3.093e6 -90 4.545e6 -110 30.e6 -110],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream='calcPSD([.0001e6 -97.5 .00399e6 -97.5 .004e6 -92.5 .025875e6 -37.5 0.138e6 -37.5 0.307e6 -90 1.221e6 -90 1.63e6 -110 30.e6 -110],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.lcname='ADSL-DMT';
tmp_tfplan.PSD.active.upstream=[25.875e3 138e3];
tmp_tfplan.PSD.active.downstream=[25.875e3 1.104e6];
tfplist=insertList(tfplist,tmp_tfplan);

% ADSL Lite (G.lite) Reference  ETSI TD 20 Villach
tmp_tfplan=def_tfplan;
tmp_tfplan.name='NP-ADSL-lite';
tmp_tfplan.PSD.downstream='calcPSD([.0001e6 -97.5 .00399e6 -97.5 .004e6 -92.5  .08e6 -72.5 0.138e6 -44.2 0.1381e6 -39.5 0.552e6 -39.5  0.956e6 -65 1.8e6 -65 2.290e6 -90 3.093e6 -90 4.545e6 -110 30.e6 -110],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream='calcPSD([.0001e6 -97.5 .00399e6 -97.5 .004e6 -92.5 .025875e6 -37.5 0.138e6 -37.5 0.307e6 -90 1.221e6 -90 1.63e6 -110 30.e6 -110],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.lcname='ADSL-lite-DMT';
tmp_tfplan.PSD.active.upstream=[25.875e3 138e3];
tmp_tfplan.PSD.active.downstream=[138e3 552e3];
tfplist=insertList(tfplist,tmp_tfplan);

% ADSL over ISDN Reference  ETSI TD 20 Villach
tmp_tfplan=def_tfplan;
tmp_tfplan.name='NP-ADSL-overISDN'; 
tmp_tfplan.PSD.downstream='calcPSD([.0001e6 -90 .05e6 -90 .080e6 -81.9 .138e6 -39.5  1.104e6 -39.5 3.093e6 -90 4.545e6 -110 30.e6 -110],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream='calcPSD([.0001e6 -90 .05e6 -90 .08e6 -81.9 .138e6 -37.5 0.276e6 -37.5 0.614e6 -90 1.221e6 -90 1.63e6 -110 30.e6 -110],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.lcname='ADSL-DMT';
tmp_tfplan.PSD.active.upstream=[138e3 2*138e3]; 
tmp_tfplan.PSD.active.downstream=[138e3 1.104e6];
tfplist=insertList(tfplist,tmp_tfplan);

% HDSL 1
tmp_tfplan=def_tfplan;
tmp_tfplan.name='NP-HDSL-1';
tmp_tfplan.PSD.downstream='calcPSD([.0001e6 -41.5 .485e6 -41.5 4.85e6 -121.5 30e6 -121.5],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream=tmp_tfplan.PSD.downstream;
tmp_tfplan.PSD.active.upstream=[.0001e6 .485e6];
tmp_tfplan.PSD.active.downstream=[.0001e6 .485e6];
tfplist=insertList(tfplist,tmp_tfplan);

% HDSL 2 (2B1Q) Reference  ETSI TD 20 Villach
tmp_tfplan=def_tfplan;
tmp_tfplan.name='NP-HDSL-2';
tmp_tfplan.PSD.downstream='calcPSD([.0001e6 -39 .292e6 -39 2.92e6 -119 30e6 -119],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream=tmp_tfplan.PSD.downstream;
tmp_tfplan.PSD.active.upstream=[0.0001e6 0.292e6];
tmp_tfplan.PSD.active.downstream=[0.0001e6 0.292e6];
tfplist=insertList(tfplist,tmp_tfplan);

% HDSL 3
tmp_tfplan=def_tfplan;
tmp_tfplan.name='NP-HDSL-3';
tmp_tfplan.PSD.downstream='calcPSD([.0001e6 -37 .196e6 -37 1.96e6 -117 30e6 -117],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream=tmp_tfplan.PSD.downstream;
tmp_tfplan.PSD.active.upstream=[1e3 196e3];
tmp_tfplan.PSD.active.downstream=[1e3 196e3];
tfplist=insertList(tfplist,tmp_tfplan);

% ISDN 2B1Q Reference  ETSI TD 20 Villach
tmp_tfplan=def_tfplan;
tmp_tfplan.name='NP-ISDN-2B1Q';
tmp_tfplan.PSD.downstream='calcPSD([.0001e6 -30 .05e6 -30 .3e6 -69 .301e6 -79  .5e6 -90 1.4e6 -90 3.637e6 -120 30e6 -120],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream=tmp_tfplan.PSD.downstream;
tmp_tfplan.PSD.active.upstream=[1e3 80e3];
tmp_tfplan.PSD.active.downstream=[1e3 80e3];
tfplist=insertList(tfplist,tmp_tfplan);

% ISDN 4B3T (for DTAG) Reference  ETSI TD 20 Villach
tmp_tfplan=def_tfplan;
tmp_tfplan.name='NP-ISDN-4B3T';
tmp_tfplan.PSD.downstream='calcPSD([.0001e6 -30 .05e6 -30 .3e6 -67 .301e6 -74  1e6 -74 4.043e6 -120 30e6 -120],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream=tmp_tfplan.PSD.downstream;
tmp_tfplan.PSD.active.upstream=[1e3 80e3];
tmp_tfplan.PSD.active.downstream=[1e3 80e3];
tfplist=insertList(tfplist,tmp_tfplan);

% ISDN PRI using a modelPSD_ISDN_PRA as a functional model
tmp_tfplan=def_tfplan;
tmp_tfplan.name='NP-ISDN-PRI';
tmp_tfplan.PSD.downstream='modelPSD_ISDN_PRA(ex.param.frequency.f)';
tmp_tfplan.PSD.upstream=tmp_tfplan.PSD.downstream;
tmp_tfplan.PSD.active.upstream=[1e3 2.1e6];
tmp_tfplan.PSD.active.downstream=[1e3 2.1e6];
tfplist=insertList(tfplist,tmp_tfplan);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%EXtension with respect to SDSL-Noise modeling according to TM6(98)10 rev. 3:

% ISDN 2B1Q (more detailed in low frequency region,
%            compared to definition above TD 20 Villach)
tmp_tfplan=def_tfplan;
tmp_tfplan.name='NP-ISDN-2B1Q-ver2';
tmp_tfplan.PSD.downstream='calcPSD([.0001e6 -31.8 .015e6 -31.8 .03e6 -33.5 .045e6 -36.6 .06e6 -42.2 .075e6 -55 .085e6 -55 .1e6 -48 .114e6 -48 .3e6 -69 .301e6 -79 .5e6 -90 1.4e6 -90 3.637e6 -120 30e6 -120 ],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream=tmp_tfplan.PSD.downstream;
tmp_tfplan.PSD.active.upstream=[1e3 80e3];  
tmp_tfplan.PSD.active.downstream=[1e3 80e3];
tfplist=insertList(tfplist,tmp_tfplan);


% HDSL 2 (2B1Q) according to TM6(98)10, rev. 5 
% (similar but different to above, why ???) 
tmp_tfplan=def_tfplan;
tmp_tfplan.name='NP-HDSL-2-ver2';
tmp_tfplan.PSD.downstream='calcPSD([.0001e6 -40.2 .1e6 -40.2 .2e6 -41.6 .3e6 -44.2 .4e6 -49.7 .5e6 -61.5 .57e6 -80 .6e6 -80 .65e6 -72 .755e6 -72  2.92e6 -119 30e6 -119],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream=tmp_tfplan.PSD.downstream;
tmp_tfplan.PSD.active.upstream=[0.0001e6 0.292e6];
tmp_tfplan.PSD.active.downstream=[0.0001e6 0.292e6];
tfplist=insertList(tfplist,tmp_tfplan);


% HDSL CAP (2-pair) according to TM6(98)10, rev. 5
tmp_tfplan=def_tfplan;
tmp_tfplan.name='NP-HDSL-CAP';
tmp_tfplan.PSD.downstream='calcPSD([.0001e6 -57 .00398e6 -57 .0215e6 -43 .03902e6 -40 .23758e6 -40 .2551e6 -43 .27262e6 -60 .297e6 -90 1.188e6 -120 30e6 -120],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream=tmp_tfplan.PSD.downstream;
tmp_tfplan.PSD.active.upstream=[1e3 196e3];
tmp_tfplan.PSD.active.downstream=[1e3 196e3];
tfplist=insertList(tfplist,tmp_tfplan);


% SDSL PSD-mask assuming 2.304 Mbps , 8kbps overhead, 3 bits per symbol (see TM6(98)10 rev. 3)
tmp_tfplan=def_tfplan;
tmp_tfplan.name='NP-SDSL';
tmp_tfplan.PSD.downstream='model_noisePSD_SDSL(ex.param.frequency.f)';
tmp_tfplan.PSD.upstream=tmp_tfplan.PSD.downstream;
tmp_tfplan.PSD.active.upstream=[1e3 .5e6]; 
tmp_tfplan.PSD.active.downstream=[1e3 .5e6];
tfplist=insertList(tfplist,tmp_tfplan);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Models of alien noises as defined in T1E1.4/99 -438R2

% HDSL model
tmp_tfplan=def_tfplan;
tmp_tfplan.name='NP-HDSL-model';
tmp_tfplan.PSD.downstream='modelPSD_HDSL(ex.param.frequency.f)';
tmp_tfplan.PSD.upstream=tmp_tfplan.PSD.downstream;
tmp_tfplan.PSD.active.upstream=[1e3 .485e6];
tmp_tfplan.PSD.active.downstream=[1e3 .485e6];
tfplist=insertList(tfplist,tmp_tfplan);

% T1 model
tmp_tfplan=def_tfplan;
tmp_tfplan.name='NP-T1-model';
tmp_tfplan.PSD.downstream='modelPSD_T1(ex.param.frequency.f)';
tmp_tfplan.PSD.upstream=tmp_tfplan.PSD.downstream;
tmp_tfplan.PSD.active.upstream=[1e3 1.544e6];
tmp_tfplan.PSD.active.downstream=[1e3 1.544e6];
tfplist=insertList(tfplist,tmp_tfplan);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Models from 012t18a1

% ADSL.FDD over POTS
% envelope power = 13.65 dBm @ 100W envelope power = 20.33 dBm @ 100W

tmp_tfplan=def_tfplan;
tmp_tfplan.name='NP-ADSL-FDDoverPOTS'; 
tmp_tfplan.PSD.downstream='calcPSD([1 -97.5 3.99e3 -97.5 4e3 -92.5 80e3 -72.5 137.99e3 -44.2 138e3 -40 1.104e6 -40 3.093e6 -90 4.545e6 -110 30e6 -110 ],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream='calcPSD([1 -97.5 3.99e3 -97.5 4e3 -92.5 25.875e3 -38 138e3 -38 307e3 -90 1.221e6 -90 1.630e6 -110 30e6 -110 ],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.lcname='ADSL-DMT';
tmp_tfplan.PSD.active.upstream=[25.875e3 138e3];
tmp_tfplan.PSD.active.downstream=[25.875e3 1.104e6];
tfplist=insertList(tfplist,tmp_tfplan);


% ADSL.FDD over ISDN
% envelope power = 14.56 dBm @ 100W envelope power = 19.83 dBm @ 100W

tmp_tfplan=def_tfplan;
tmp_tfplan.name='NP-ADSL-FDDoverISDN'; 
tmp_tfplan.PSD.downstream='calcPSD([1 -90 93.1e3 -90 209e3 -62 253.99e3 -48.5 254e3 -40 1104e3 -40 3093e3 -90 4545e3 -110 30e6 -110 ],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream='calcPSD([1 -90 50e3 -90 80e3 -81.9 120e3 -38 276e3 -38 614e3 -90 1.221e6 -90 1.630e6 -110 30e6 -110 ],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.lcname='ADSL-DMT';
tmp_tfplan.PSD.active.upstream=[120e3 276e3];
tmp_tfplan.PSD.active.downstream=[254e3 1.104e6];
tfplist=insertList(tfplist,tmp_tfplan);
